@@ -1,13 +1,12 @@
 from rest_framework import serializers
 
-from netbox.api.serializers import NetBoxModelSerializer
-from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer, \
-    NestedLinuxVolumeSerializer
-from netbox_storage.models import Drive, Filesystem, LinuxVolume, LinuxVolumeDrive
+from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer
+from netbox_storage.models import Drive, Filesystem, LinuxVolume, WindowsVolume
 from virtualization.api.nested_serializers import NestedClusterSerializer, NestedVirtualMachineSerializer
 
 
 class FilesystemSerializer(serializers.ModelSerializer):
+
     class Meta:
         model = Filesystem
         fields = (
@@ -20,17 +19,14 @@ class FilesystemSerializer(serializers.ModelSerializer):
         )
 
 
-class DriveSerializer(NetBoxModelSerializer):
+class DriveSerializer(serializers.ModelSerializer):
     cluster = NestedClusterSerializer(required=False, allow_null=True)
     virtual_machine = NestedVirtualMachineSerializer(required=False, allow_null=True)
-    url = serializers.HyperlinkedIdentityField(view_name="plugins-api:netbox_storage-api:drive-detail")
 
     class Meta:
         model = Drive
         fields = (
             "id",
-            "url",
-            "display",
             "size",
             "cluster",
             "virtual_machine",
@@ -60,17 +56,19 @@ class LinuxVolumeSerializer(serializers.ModelSerializer):
         )
 
 
-class LinuxVolumeDriveSerializer(serializers.ModelSerializer):
-    drive = NestedDriveSerializer(required=False, allow_null=True)
-    linuxvolume = NestedLinuxVolumeSerializer(required=False, allow_null=True)
+class WindowsVolumeSerializer(serializers.ModelSerializer):
+    fs = NestedFilesystemSerializer(required=False, allow_null=True)
+    drives = NestedDriveSerializer(required=False, allow_null=True)
+    virtual_machine = NestedVirtualMachineSerializer(required=False, allow_null=True)
 
     class Meta:
-        model = LinuxVolumeDrive
+        model = WindowsVolume
         fields = (
             "id",
-            "allocation",
-            "drive",
-            "linuxvolume",
+            "drive_name",
+            "fs",
+            "drives",
+            "virtual_machine",
             "description",
             "created",
             "last_updated",
