@@ -13,6 +13,7 @@ from utilities.forms import (
 )
 
 from netbox_storage.models import Filesystem, WindowsVolume, Drive
+from virtualization.models import VirtualMachine
 
 
 class WindowsVolumeForm(NetBoxModelForm):
@@ -28,6 +29,11 @@ class WindowsVolumeForm(NetBoxModelForm):
     drives = DynamicModelMultipleChoiceField(
         queryset=Drive.objects.all(),
         label="Drives",
+        required=False
+    )
+    virtual_machine = DynamicModelChoiceField(
+        queryset=VirtualMachine.objects.all(),
+        required=False
     )
 
     class Meta:
@@ -37,6 +43,7 @@ class WindowsVolumeForm(NetBoxModelForm):
             "drive_name",
             "fs",
             "drives",
+            "virtual_machine",
             "description",
         )
 
