@@ -2,6 +2,7 @@ from django.db import models
 from django.urls import reverse
 
 from netbox.models import NetBoxModel
+from netbox.search import SearchIndex, register_search
 
 
 class Drive(NetBoxModel):
@@ -26,7 +27,7 @@ class Drive(NetBoxModel):
         blank=True,
     )
 
-    clone_fields = ["size", "identifier", "cluster", "virtual_machine", "description"]
+    clone_fields = ["size", "cluster", "virtual_machine", "description"]
 
     prerequisite_models = (
         'virtualization.Cluster',
@@ -42,20 +43,13 @@ class Drive(NetBoxModel):
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:drive", kwargs={"pk": self.pk})
 
+    # this is not needed if small_image is created at set_image
     def save(self, *args, **kwargs):
-        is_already_implemented = Drive.objects.filter(id=self.pk).count()
-        if is_already_implemented == 0:
-            number_of_hard_drives = Drive.objects.filter(virtual_machine=self.virtual_machine).order_by("created")\
-                .count()
-
-            self.identifier = f"Hard Drive {number_of_hard_drives + 1}"
+        number_of_hard_drives = Drive.objects.filter(virtual_machine=self.virtual_machine).order_by("created").count()
 
+        self.identifier = f"Hard Drive {number_of_hard_drives + 1}"
         super(Drive, self).save(*args, **kwargs)
 
-    @property
-    def docs_url(self):
-        return f'https://confluence.ti8m.ch/docs/models/drive/'
-
 
 class Filesystem(NetBoxModel):
     filesystem = models.CharField(
@@ -118,19 +112,25 @@ class LinuxVolume(NetBoxModel):
         ordering = ("vg_name", "lv_name", "path")
 
 
-class LinuxVolumeDrive(NetBoxModel):
-    drive = models.ForeignKey(
+class WindowsVolume(NetBoxModel):
+    drive_name = models.CharField(
+        max_length=255,
+    )
+    fs = models.ForeignKey(
+        Filesystem,
+        on_delete=models.CASCADE,
+        related_name="fs_windows",
+        verbose_name="Filesystem",
+    )
+    drives = models.ManyToManyField(
         Drive,
-        on_delete=models.CASCADE,
-        related_name='drive_linuxvolume',
+        related_name="drives",
+        verbose_name="Drives",
     )
-    linuxvolume = models.ForeignKey(
-        LinuxVolume,
+    virtual_machine = models.ForeignKey(
+        to='virtualization.VirtualMachine',
         on_delete=models.CASCADE,
-        related_name='linuxvolume',
-    )
-    allocation = models.PositiveIntegerField(
-        verbose_name="Allocation"
+        related_name='drive_volume',
     )
     description = models.CharField(
         max_length=255,
@@ -138,17 +138,18 @@ class LinuxVolumeDrive(NetBoxModel):
     )
 
     clone_fields = [
-            "drive",
-            "linuxvolume",
-            "allocation",
+            "drive_name",
+            "fs",
+            "drives",
+            "virtual_machine",
             "description",
         ]
 
     def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:linuxvolumedrive", kwargs={"pk": self.pk})
+        return reverse("plugins:netbox_storage:windowsvolume", kwargs={"pk": self.pk})
 
     def __str__(self):
-        return f"{self.drive}-{self.linuxvolume}"
+        return f"Name: {self.drive_name} filesystem: {self.fs}"
 
     class Meta:
-        ordering = ("drive", "linuxvolume")
+        ordering = ("drive_name", "fs")
