@@ -3,13 +3,15 @@ import django_tables2 as tables
 from netbox.tables import (
     NetBoxTable,
     ToggleColumn,
+    ActionsColumn,
 )
 
 from netbox_storage.models import WindowsVolume
 
 
-class WindowsVolumeTable(NetBoxTable):
-    """Table for displaying WindowsVolume objects."""
+class WindowsVolumeBaseTable(NetBoxTable):
+    """Base class for tables displaying WindowsVolume"""
+
     fs = tables.Column(
         linkify=True,
     )
@@ -21,6 +23,10 @@ class WindowsVolumeTable(NetBoxTable):
         linkify=True
     )
 
+
+class WindowsVolumeTable(WindowsVolumeBaseTable):
+    """Table for displaying WindowsVolume objects."""
+
     pk = ToggleColumn()
 
     class Meta(NetBoxTable.Meta):
@@ -36,6 +42,24 @@ class WindowsVolumeTable(NetBoxTable):
         default_columns = (
             "drive_name",
             "fs",
-            "drives",
-            "virtual_machine"
+            "description"
         )
+
+
+class RelatedWindowsVolumeTable(WindowsVolumeBaseTable):
+    actions = ActionsColumn(actions=())
+
+    class Meta(NetBoxTable.Meta):
+        model = WindowsVolume
+        fields = (
+            "pk",
+            "drive_name",
+            "fs",
+            "description",
+        )
+        default_columns = (
+            "drive_name",
+            "fs",
+            "description"
+        )
+
